package main

import (
	"capstone-project/config"
	"capstone-project/entity"
	"capstone-project/repository"
	"capstone-project/route"
	"capstone-project/service"
	"net/http"
	"os"

	"github.com/joho/godotenv"
)

func init() {
	err := godotenv.Load(".env")
	if err != nil {
		panic(err)
	}
}

func main() {
	var (
		db         = config.InitDatabase()
		PORT       = os.Getenv("PORT")
		repository = repository.NewRepository(db)
		service    = service.NewService(repository)
	)
	entity.DB.AutoMigrate(&entity.Points{}, &entity.Users{}, &entity.Products{}, &entity.SerialNumbers{}, &entity.Transactions{}, &entity.FAQ{})
	app := route.New(service)

	app.Start(":" + PORT)
}

func Handler(w http.ResponseWriter, r *http.Request) {
	var (
		db         = config.InitDatabase()
		repository = repository.NewRepository(db)
		service    = service.NewService(repository)
	)

	app := route.New(service)
	app.ServeHTTP(w, r)
}
